"""Nile plugin adding coverage reports for Cairo Smart Contracts."""
import logging

__author__ = "Eric Nordelo"
__copyright__ = "Eric Nordelo"
__license__ = "MIT"

logger = logging.getLogger(__name__)
